%Code used in analysis of data for Guiraud et al. 'Discrimination of edge
%orientation by bumblebees'.
%
%Requires dataset "Data Guiraud et al Discrimination of edge orientation by bumblebees.xlsx".
%
%This code requires the function "permutationTest", Copyright 2015-2018,
%2021 Laurens R Krol, available from https://uk.mathworks.com/matlabcentral/fileexchange/63276-permutation-test
%
%Other code: Joseph Woodgate, 2020-2021

%% USER INPUTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Path to data spreadsheet
pathdata='D:\Data Guiraud et al Discrimination of edge orientation by bumblebees.xlsx';

%Maximum number of 10-trial blocks experienced by any bee.
nochoices=19;
%For analysing differences between groups of bees in Experiment 1 trained
%on different angles, specify minimum number of bees in each group. The
%analysis will use only groups with at least this many bees in them.
minno=3;
%For regression analysis of learning rate, specify the proportion of
%correct choices required (over two consecutive 10-trial blocks) to
%classify a bee as havnig learned the task. We will only look at learning
%rate util the bee reaches this threshold, since performance is likely to
%plateau above this point.
learningthreshold=0.8;

% Now press 'run' %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not alter any code below this point %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Process dataset to acquire variables %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Import data
opts= detectImportOptions(pathdata);
A=readtable(pathdata, opts);

%% Process data and add new variables
A.TrainingChoices=cell(size(A.BeeNo));
A.AboveThreshold=zeros(size(A.BeeNo));
A.AboveThresholdAfter=NaN(size(A.BeeNo));
A.Last20PropCorrect=NaN(size(A.BeeNo));
    tempCS=[A.CS_Plus A.CS_Minus];
    A.CS_Pair=sort(tempCS,2);
    [~, ~, A.BaseAngle2]=unique(A.CS_Pair, 'rows');

[B.BeeID, bsort]=sort(repmat(A.BeeNo, nochoices,1));
B.BeeID=repmat(A.BeeID, nochoices,1); B.BeeID=B.BeeID(bsort);
B.BeeNo=repmat(A.BeeNo, nochoices,1); B.BeeNo=B.BeeNo(bsort);
B.MultiOrDual=repmat(A.MultiOrDual, nochoices,1); B.MultiOrDual=B.MultiOrDual(bsort);
B.MaxChoices=repmat(A.MaxChoices, nochoices,1); B.MaxChoices=B.MaxChoices(bsort);
B.AngleDiff=repmat(A.AngleDiff, nochoices,1); B.AngleDiff=B.AngleDiff(bsort);
B.CS_Plus=repmat(A.CS_Plus, nochoices,1); B.CS_Plus=B.CS_Plus(bsort);
B.CS_Minus=repmat(A.CS_Minus, nochoices,1); B.CS_Minus=B.CS_Minus(bsort);
B.BaseAngle=repmat(A.BaseAngle, nochoices,1); B.BaseAngle=B.BaseAngle(bsort);
B.TrialNo=repmat((10:10:10*nochoices)', length(A.BeeNo), 1);
B.IgnoreBlock=zeros(nochoices*length(A.BeeNo),1);
B.TrainingChoices=zeros(nochoices*length(A.BeeNo),1);
B.TwoBlockSuccess=zeros(nochoices*length(A.BeeNo),1);
B.AboveThreshold=zeros(nochoices*length(A.BeeNo),1);
if istable(B)==0; B=struct2table(B); end

bstarts=(1:nochoices:length(B.BeeID))';
bends=(nochoices:nochoices:length(B.BeeID))';

%% Determine which bees passed learning threshold and at what stage they had learned
for bind=1:length(A.BeeNo)
    temptrainingchoices=[...
A.Choices_10(bind);...
A.Choices_20(bind);...
A.Choices_30(bind);...
A.Choices_40(bind);...
A.Choices_50(bind);...
A.Choices_60(bind);...
A.Choices_70(bind);...
A.Choices_80(bind);...
A.Choices_90(bind);...
A.Choices_100(bind);...
A.Choices_110(bind);...
A.Choices_120(bind);...
A.Choices_130(bind);...
A.Choices_140(bind);...
A.Choices_150(bind);...
A.Choices_160(bind);...
A.Choices_170(bind);...
A.Choices_180(bind);...
A.Choices_190(bind);...
    ];

A.TrainingChoices{bind}=temptrainingchoices;
B.TrainingChoices(bstarts(bind):bends(bind))=temptrainingchoices;
 tempignore=ones(nochoices,1); tempignore(~isnan(temptrainingchoices))=0;
B.IgnoreBlock  (bstarts(bind):bends(bind))=tempignore;
    temptwoblocksuccess=[NaN; (temptrainingchoices(1:end-1)+temptrainingchoices(2:end))./20];
B.TwoBlockSuccess(bstarts(bind):bends(bind))=temptwoblocksuccess;
    firstlearn=find(temptwoblocksuccess>=learningthreshold,1);
A.Last20PropCorrect(bind)=temptwoblocksuccess(find(~isnan(temptwoblocksuccess),1,'last'));
    if isempty(firstlearn)==0
        A.AboveThreshold(bind)=1;
        A.AboveThresholdAfter(bind)=10*firstlearn;
            templearn=zeros(nochoices,1); templearn(firstlearn:end)=1;
            templearnforreg=zeros(nochoices,1); templearnforreg(firstlearn+1:end)=1;
        B.AboveThreshold(bstarts(bind):bends(bind))=templearn;
    end

end %for bind=1:length(A.BeeNo)

%% Compile details on how many bees learned or failed in each experiment
[exptdetails, ~, expt]=unique([A.AngleDiff A.MultiOrDual], 'rows', 'stable');
A.Experiment=expt;
[bexptdetails, ~, bexpt]=unique([B.AngleDiff B.MultiOrDual], 'rows', 'stable');
B.Experiment=bexpt;
Experiment.AngleDiff=exptdetails(:,1);
Experiment.MultiOrDual=exptdetails(:,2);
Experiment.NoAboveThreshold=NaN(size(Experiment.AngleDiff));
Experiment.NoBelowThreshold=NaN(size(Experiment.AngleDiff));
Experiment.NoBees=NaN(size(Experiment.AngleDiff));
Experiment.PropnAboveThreshold=NaN(size(Experiment.AngleDiff));
Experiment.Details=cell(size(Experiment.AngleDiff));
for eind=1:length(exptdetails)
    inexpt=find(expt==eind);
    Experiment.NoBees(eind)=length(inexpt);
    Experiment.NoAboveThreshold(eind)=sum(A.AboveThreshold(inexpt)==1);
    Experiment.NoBelowThreshold(eind)=sum(A.AboveThreshold(inexpt)==0);
end

Experiment.PropnAboveThreshold=Experiment.NoAboveThreshold./Experiment.NoBees;
if istable(Experiment)==0
    Experiment=struct2table(Experiment);
end

%% Analyse data %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Start results summary
summary={};

%% Summarise Experiment 1 results, test whether bees performed better than chance
thisexpt=1;
summary=addsum(thisexpt, summary, A);

%% Experiment 1: Test whether base angle affects final learning performance or learning speed
thisexpt=1;
thesebees=find(A.Experiment==thisexpt) ;
theselearned=A.AboveThreshold(thesebees);
AngleGroups=[];
[AngleGroups.BaseAngle,~,anggroups]=unique(A.BaseAngle(thesebees));
AngleGroups.GroupNo=unique(anggroups);
AngleGroups.NoBees_Total=zeros(size(AngleGroups.BaseAngle));
AngleGroups.NoBees_AboveThreshold=zeros(size(AngleGroups.BaseAngle));
for gind=1:length(AngleGroups.BaseAngle)
    AngleGroups.NoBees_Total(gind)=sum(anggroups==AngleGroups.GroupNo(gind));
    AngleGroups.NoBees_AboveThreshold(gind)=sum(theselearned(anggroups==AngleGroups.GroupNo(gind)));
end %for gind=1:length(ag)
AngleGroups=struct2table(AngleGroups);

usegroup=AngleGroups.GroupNo(AngleGroups.NoBees_Total>=minno);
thesebees=thesebees(ismember(anggroups,usegroup));
anggroups=anggroups(ismember(anggroups,usegroup));

%Compare proportion correct choices over last 2 blocks of trials, between groups with different base angle 
  [last20p,last20tbl,last20stats] = kruskalwallis(A.Last20PropCorrect(thesebees), anggroups, 'off');
summary=[summary; cellstr(['Kruskal-Wallis test: proportion correct choices over last 20 trials, by base angle: Chi-sq = ' num2str(last20tbl{2,5}, '%.2f') ', d.f. = ' num2str(last20tbl{2,3}) ',' num2str(last20tbl{3,3}) ', ' pstring(last20tbl{2,6})])];

%Use GLM to test effect of trial block no (i.e. experience) and base angle
%on rate of learning
RTab=[];
theseb=find(B.AboveThreshold==0 & B.Experiment==thisexpt & ~isnan(B.TrainingChoices) & ismember(B.BaseAngle, AngleGroups.BaseAngle(usegroup)));
RTab.BlockNo=B.TrialNo(theseb)./10;
    [~, locb]=ismember(B.BaseAngle, AngleGroups.BaseAngle);
RTab.BaseAngleGroup=categorical(locb(theseb));
RTab.BeeNo=categorical(B.BeeNo(theseb));
RTab.Response=asin(sqrt(B.TrainingChoices(theseb)./10)); %arcsine-square-root transformed proportion correct choices
RTab=struct2table(RTab);

formula = 'Response ~ BlockNo + BlockNo:BaseAngleGroup + (1|BeeNo)'; %main effect of block only, plus block*angle interaction
glme = fitglme(RTab,formula, 'DummyVarCoding','effects');
regstats=anova(glme);
summary=[summary; cellstr(['GLM: Proportion correct choices per block, effect of block no: F = ' num2str(regstats{2,2}, '%.2f') ', d.f. = ' num2str(regstats{2,3}) ',' num2str(regstats{2,4}) ', ' pstring(regstats{2,5})])];
summary=[summary; cellstr(['GLM: Proportion correct choices per block, interaction block*base_angle: F = ' num2str(regstats{3,2}, '%.2f') ', d.f. = ' num2str(regstats{3,3}) ',' num2str(regstats{3,4}) ', ' pstring(regstats{3,5})])];

 summary=[summary; cellstr(['________________________________________'])]; 
 summary=[summary; cellstr([''])];


%% Summarise Experiment 2 results, test whether bees performed better than chance
thisexpt=2;
summary=[summary; cellstr([''])];
summary=addsum(thisexpt, summary, A);

%% Compare Experiments 1 vs 2: test whether training paradigm affects final performance or speed of learning
 summary=[summary; cellstr([''])];
 summary=[summary; cellstr(['Experiment 1 vs 2'])];   
 summary=[summary; cellstr(['----------------------------------------'])];

%Compare proportion correct choices over last 2 blocks of trials, between groups with different base angle 
[permp, permod, permeffectsize] = permutationTest(20*A.Last20PropCorrect(A.Experiment==1 & ~isnan(A.Last20PropCorrect)), 20*A.Last20PropCorrect(A.Experiment==2 & ~isnan(A.Last20PropCorrect)), [],  'exact', 1);
summary=[summary; cellstr(['Permutation test: does proportion correct choices over last 20 trials differ between experiments? ' pstring(permp) ', Hedges'' g (effect size) = ' num2str(permeffectsize, '%.3f')])];

%Use GLM to test effect of trial block no (i.e. experience) and experiment
%on rate of learning
RTab2=[];
theseb=find(B.AboveThreshold==0 & ~isnan(B.TrainingChoices));
RTab2.BlockNo=B.TrialNo(theseb)./10;
RTab2.Experiment=categorical(B.Experiment(theseb));
RTab2.BeeNo=categorical(B.BeeNo(theseb));
RTab2.Response=asin(sqrt(B.TrainingChoices(theseb)./10)); %arcsine-square-root transformed proportion correct choices
RTab2=struct2table(RTab2);

formula = 'Response ~ BlockNo + BlockNo:Experiment + (1|BeeNo)'; %main effect of block only, plus block*angle interaction
glme = fitglme(RTab2,formula, 'DummyVarCoding','effects');
regstats2=anova(glme);
summary=[summary; cellstr(['GLM: Proportion correct choices per block, effect of block no: F = ' num2str(regstats2{2,2}, '%.2f') ', d.f. = ' num2str(regstats2{2,3}) ',' num2str(regstats2{2,4}) ', ' pstring(regstats2{2,5})])];
summary=[summary; cellstr(['GLM: Proportion correct choices per block, interaction block*experiment: F = ' num2str(regstats2{3,2}, '%.2f') ', d.f. = ' num2str(regstats2{3,3}) ',' num2str(regstats2{3,4}) ', ' pstring(regstats2{3,5})])];

 summary=[summary; cellstr(['________________________________________'])]; 
 summary=[summary; cellstr([''])];

%% Print results summary
disp(char(summary));

%% Create figures %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Create Fig 2: learning curves
%Settings
exptlist=unique(A.Experiment);
linewidth=1.5;
markersize=6;
cols=[0.75 0.2 0.2;
      0.2 0.2 0.75;
      1 0.7 0.7;
      0.7 0.7 1;
      1 0.9 0.9;
      0.9 0.9 1
      ];
markers={'o', 'o'};
miny=1;
maxx=1;

%Create figure
F2=figure;
hold all;

for eind=1:length(exptlist)
    %For each experiment, compile matrix with each bee's performance
    thisexpt=exptlist(eind);
    thesebees=find(A.Experiment==thisexpt);
    thesechoices=NaN(length(thesebees),size(A.TrainingChoices{1},1));
        for thisind=1:length(thesebees)
            thesechoices(thisind,:)=A.TrainingChoices{thesebees(thisind)}';
            
        end %for thisind=1:length(thesebees)
        thesechoices=thesechoices./10;

    %Work out mean performance and standard error    
    meancorrect=mean(thesechoices,1, 'omitnan');
    stdcorrect=std(thesechoices,1, 'omitnan');
        nancorrect=~isnan(thesechoices);
    sumcorrect=sum(nancorrect,1); sumcorrect(sumcorrect==0)=NaN;
    secorrect=stdcorrect./sqrt(sumcorrect);
    xcorrect=10*(1:length(meancorrect));
    usable=sumcorrect>0; usable(xcorrect>250)=0;
    
    %Work out axis limits
    miny=min([miny; min(meancorrect(usable)-secorrect(usable))]);
    maxx=max([maxx; max(xcorrect(usable))]);

    %Plot mean performance with error bars
    errorbar(xcorrect(usable), meancorrect(usable), secorrect(usable),...
        'Color', cols(eind,:), 'LineWidth', linewidth, 'Marker', markers{eind},...
        'Markersize', markersize, 'MarkerFaceColor', cols(eind,:), 'MarkerEdgeColor', 'none');
end %for eind=1:length(exptlist)

%Plot reference lines
plot([0 maxx+10], [0.5 0.5], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);
plot([0 maxx+10], [0.8 0.8], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);

%Format figure
set(gca,'XLim',[0 maxx+10]);
set(gca,'YLim',[0 1.05]);
set(gca,'YTick',0:0.2:1);
set(gca,'FontName', 'Arial'); 
set(gca,'FontSize', 16); 
pbaspect([5 4 1]);
set(gcf,'Position', [100 100 (5/4*600) 600 ]); 
set(gca,'linewidth',1.5);
set(gcf,'Position', [100 100 (5/4*600) 600 ]); 
set(gcf,'OuterPosition', [549.8000   97.0000  764.0000  689.6000]); 
set(gcf,'InnerPosition',[557 104.2000 749.6000 600]);

%% Create Fig 3A: Experiment 1, learning curves for each group of bees trained on a different base angle
%Settings
thisexpt=1;
linewidth=1.5;
markersize=6;
cols=[1 0.55 0.55;
      0.55 0.55 1;
      0.55 1 0.55;
      ];
markers={'^', 'o', 's'};
miny=1;
maxx=1;

%Create figure;
F3A=figure;
hold all;

%Work out which bees should be used
usebees=find(A.Experiment==thisexpt) ;
[~,~,anggroups]=unique(A.BaseAngle(usebees));
usebees=usebees(ismember(anggroups,usegroup));
anggroups=anggroups(ismember(anggroups,usegroup));


for eind=1:length(usegroup)
    %For each group (trained on a different base angle), compile matrix
    %with each bee's performance
    thisgroup=usegroup(eind);
    thesebees=usebees(anggroups==thisgroup);
    thesechoices=NaN(length(thesebees),size(A.TrainingChoices{1},1));
        for thisind=1:length(thesebees)
            thesechoices(thisind,:)=A.TrainingChoices{thesebees(thisind)}';
        end %for thisind=1:length(thesebees)
        thesechoices=thesechoices./10;

    %Work out mean performance and standard error 
    meancorrect=nanmean(thesechoices,1);
    stdcorrect=nanstd(thesechoices,1);
        nancorrect=isnan(thesechoices)==0;
    sumcorrect=sum(nancorrect,1); sumcorrect(sumcorrect==0)=NaN;
    secorrect=stdcorrect./sqrt(sumcorrect);
    xcorrect=10*(1:length(meancorrect));
    usable=sumcorrect>0; usable(xcorrect>250)=0;
    
    %Work out axis limits
    miny=min([miny; min(meancorrect(usable)-secorrect(usable))]);
    maxx=max([maxx; max(xcorrect(usable))]);
    
    %Plot mean performance with error bars
    errorbar(xcorrect(usable), meancorrect(usable), secorrect(usable),...
        'Color', cols(eind,:), 'LineWidth', linewidth, 'Marker', markers{eind},...
        'Markersize', markersize, 'MarkerFaceColor', cols(eind,:), 'MarkerEdgeColor', 'none');
    
end %for eind=1:length(exptlist)

%Plot reference lines
plot([0 maxx+10], [0.5 0.5], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);
plot([0 maxx+10], [0.8 0.8], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);

%Format figure
set(gca,'XLim',[0 200]);
% set(gca,'XLim',[0 maxx+10]);
set(gca,'YLim',[0 1.05]);
set(gca,'YTick',0:0.2:1);
set(gca,'FontName', 'Arial'); 
set(gca,'FontSize', 16); 
pbaspect([5 4 1]);
set(gcf,'Position', [100 100 (5/4*600) 600 ]); 
set(gca,'linewidth',1.5);
set(gcf,'Position', [100 100 (5/4*600) 600 ]); 
set(gcf,'OuterPosition', [549.8000   97.0000  764.0000  689.6000]); 
set(gcf,'InnerPosition',[557 104.2000 749.6000 600]);

%% Create Fig 3B: Boxplots showing proportion correct choices over last two 10-trial blocks for each group of bees trained on a different base angle
%Settings
thisexpt=1;
linewidth=1.5;
markersize=6;
cols=[1 0.55 0.55;
      0.55 0.55 1;
      0.55 1 0.55;
      ];
markers={'^', 'o', 's'};
miny=1;
maxx=1;
ydata=A.Last20PropCorrect;
 gps=NaN(size(usegroup));
gps(usegroup)=(1:length(usegroup))';

%Create figure
F3B=figure;
hold all;

%Plot reference lines
plot([gps(1)-0.5 gps(end)+0.5], [0.5 0.5], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);
plot([gps(1)-0.5 gps(end)+0.5], [0.8 0.8], 'LineStyle', '--', 'LineWidth', 1, 'Color', [0.6 0.6 0.6]);

%Plot individual bees' data as scatter plot
    xout=JLWjitter(gps(anggroups), ydata(usebees), 0.1);
scatter(xout,ydata(usebees), [], cols(gps(anggroups),:), 'filled',  'jitter','on', 'jitterAmount',0.025);

%Make boxplots
boxplot(ydata(usebees), gps(anggroups), 'Colors', [0 0 0], 'Whisker', 10);

%Format figure
set(findobj(gca,'type','line'),'linew',linewidth);
set(findobj(gcf, 'type', 'line', 'Tag', 'Median'), 'Color', [0.75 0.1 0.1], 'linew', 2);
set(gca,'Box','off');
set(gca,'XLim',[gps(1)-0.5 gps(end)+0.5]);
set(gca,'XTick',unique(gps(~isnan(gps))));
set(gca,'XTickLabel',[]);
% set(gca,'YLim',[0 max(ydata(allbees))+10]);
set(gca,'YLim',[0 1.05]);
set(gca,'YTick',0:0.2:1);
set(gca,'FontName', 'Arial'); 
set(gca,'FontSize', 16);
set(gca,'linewidth',1.5);
pbaspect([5 4 1]);
set(gcf,'Position', [100 100 (5/4*600) 600 ]); 
set(gcf,'OuterPosition', [549.8000   97.0000  764.0000  689.6000]); 
set(gcf,'InnerPosition',[557 104.2000 749.6000 600]);

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function summary=addsum(thisexpt,summary, A)

thesebees=find(A.Experiment==thisexpt);
 summary=[summary; cellstr(['Experiment ' num2str(thisexpt) ':'])];   
 summary=[summary; cellstr(['----------------------------------------'])];
 summary=[summary; cellstr(['No bees = ' num2str(length(thesebees))])];    
 summary=[summary; cellstr(['No reached 80% correct choices = ' num2str(sum(A.AboveThreshold(thesebees))) '; No failed to reach 80% = ' num2str(sum(A.AboveThreshold(thesebees)==0))])]; 

 learnedaftermean=mean(A.AboveThresholdAfter(thesebees), 'omitnan');
 learnedafterSD=std(A.AboveThresholdAfter(thesebees), 'omitnan');
 learnedafterSE=learnedafterSD/sqrt(sum(~isnan(A.AboveThresholdAfter(thesebees))));
summary=[summary; cellstr(['Bees reached 80% correct choices after = ' num2str(learnedaftermean, '%.2f') ' +/- ' num2str(learnedafterSE, '%.2f') ' trials (SD = ' num2str(learnedafterSD, '%.2f') '; range = ' num2str(min(A.AboveThresholdAfter(thesebees), [], 'omitnan')) ' : ' num2str(max(A.AboveThresholdAfter(thesebees), [], 'omitnan')) ')'])];
summary=[summary; cellstr([''])];

  last20propcorrectmean=mean(A.Last20PropCorrect(thesebees), 'omitnan');
  last20propcorrectSD=std(A.Last20PropCorrect(thesebees), 'omitnan');
  last20propcorrectSE=last20propcorrectSD/sqrt(sum(~isnan(A.Last20PropCorrect(thesebees))));
summary=[summary; cellstr(['Proportion correct choices over last 20 trials = ' num2str(last20propcorrectmean, '%.3f') ' +/- ' num2str(last20propcorrectSE, '%.3f') ' (SD = ' num2str(last20propcorrectSD, '%.3f') ')'])];

 [wp,~,wstats] = signrank(A.Last20PropCorrect(thesebees), 0.5);
summary=[summary; cellstr(['One-sample Wilcoxon signed rank test: Proportion correct choices over last 20 trials vs chance: V = ' num2str(wstats.signedrank) ', N = ' num2str(length(thesebees)) ', ' pstring(wp)])];

if sum(~isnan(A.LT_TotalChoices(thesebees)))>0
    summary=[summary; cellstr([''])];
      LTpropcorrectmean=mean(A.LT_PropCorrect(thesebees), 'omitnan');
      LTpropcorrectSD=std(A.LT_PropCorrect(thesebees), 'omitnan');
      LTpropcorrectSE=LTpropcorrectSD/sqrt(sum(~isnan(A.LT_PropCorrect(thesebees))));
    summary=[summary; cellstr(['Proportion ''correct'' choices in learning test = ' num2str(LTpropcorrectmean, '%.3f') ' +/- ' num2str(LTpropcorrectSE, '%.3f') ' (SD = ' num2str(LTpropcorrectSD, '%.3f') ')'])];
    
     [wp,~,wstats] = signrank(A.LT_PropCorrect(thesebees), 0.5);
    summary=[summary; cellstr(['One-sample Wilcoxon signed rank test: Proportion ''correct'' choices in learning test vs chance: V = ' num2str(wstats.signedrank) ', N = ' num2str(length(thesebees)) ', ' pstring(wp)])];
end %if sum(~isnan(A.LT_TotalChoices(thesebees)))>0
 
 summary=[summary; cellstr(['________________________________________'])]; 
 summary=[summary; cellstr([''])];

end %function summary=addsum(thisexpt,summary)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function pout=pstring(pin)
    if pin>=0.001
        pout=['P = ' num2str(pin, '%.3f')];
    elseif pin>=0.0001
        pout='P < 0.001';
    else
        pout='P < 0.0001';
    end
end %function pout=pstring(pin)

%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function xout=JLWjitter(xin, yin, maxjitter, jittertype)

if nargin<4 | isempty(jittertype)==1
    jittertype=1;
end
if nargin<3 | isempty(maxjitter)==1
    maxjitter=1;
end

xout=NaN(size(xin));

if jittertype==1 %work out how far apart x-values need to be spaced inb order to make the maximum x-interval equal to +/- maxjitter. Then ensure all datapoints separated by this value and symmetrical
    [~, ~, xind]=unique([xin yin],'rows');

    xvals=histcounts(xind,[0.5:1:length(unique(xind))+0.5]);

    if max(xvals)>1
    mostgaps=max(xvals)-1;
    jitunit=(2*maxjitter)/mostgaps;
        for xvind=1:length(unique(xind))
            thisx=find(xind==xvind);
            xout(thisx)=xin(thisx) + ((0:jitunit:(length(thisx)-1)*jitunit)- (0.5*((length(thisx)-1)*jitunit)))';


        end %for xvind=1:length(xvals)
    else
        xout=xin;
    end %if max(xvals)>1
elseif jittertype==2 %for each value of x, work out the shape of an ellipse with maximum width equal to +/- maxjitter and arrange datapoints randomly within the ellipse
        xvals=unique(xin);
        tempx=NaN(size(xin));
        %for each value of x, work out the shape of an ellipse which has a
        %height equal to the range of y-values in that x-category and a width
        %equal to one
    for xind=1:length(xvals)
        thisx=xvals(xind);
        theseind=find(xin==thisx & isnan(yin)==0);
        if isempty(theseind)==0
            thesey=yin(theseind);
          ellwidth=1;
          ellheight=(max(thesey)-min(thesey))/2;
          if ellheight<=0
              ellx=ones(size(thesey));
          else
          ellcenter=min(thesey)+ellheight;

          ellx=sqrt(abs((ellwidth^2).*(1-(((thesey-ellcenter).^2)/(ellheight.^2)))));
          end    %if ellheight<=0      
          tempx(theseind)=ellx;
        end %if isempty(theseind)==0
    end %for xind=1:length(xin)

    %for each y value, calculate the interval within which the x value can be
    %jittered: this is the width of an ellipse whose maximum width is
    %maxjitter, at the appropriate y-value
    intervalwidth=tempx*2*maxjitter;
    intervall=tempx*-maxjitter;
    %get a random number to be a seed for the x value for each y-value. The
    %true x will be this random proportion across the ellipse width interval we
    %have just calculated
    propinterval=rand(size(yin));
    intervalx=intervall+(propinterval.*intervalwidth);
    xout=xin+intervalx;
end %if jittertype==1
end % fuction end